@@ -1,5 +1,6 @@
 import json
 import os
+import getpass
 from socket import gethostname
 from dataclasses import dataclass, fields
 from typing import List, Dict
@@ -26,6 +27,7 @@ class FireXRunData:
     results: Dict = None
     revoked: bool = False
 
+
 class FireXJsonReportGenerator:
     formatters = ('json',)
 
@@ -35,13 +37,15 @@ class FireXJsonReportGenerator:
     report_link_filename = 'run.json'
 
     @staticmethod
-    def get_common_run_data(uid, chain, submission_dir, argv, original_cli):
-        data = {'chain': [t.short_name for t in get_app_tasks(chain)],
-                'firex_id': str(uid),
+    def get_common_run_data(uid, chain, submission_dir, argv, original_cli, inputs):
+        data = {**uid.run_data,
+                'chain': [t.short_name for t in get_app_tasks(chain)],
                 'logs_path': uid.logs_dir,
                 'submission_host': app.conf.mc or gethostname(),
                 'submission_dir': submission_dir,
                 'submission_cmd': original_cli or list(argv),
+                'submitter': getpass.getuser(),
+                'inputs': inputs
                 }
 
         viewers = uid.viewers or {}
@@ -63,13 +67,18 @@ class FireXJsonReportGenerator:
                       indent=4)
 
     @staticmethod
-    def create_initial_run_json(uid, chain, submission_dir, argv, original_cli=None, json_file=None, **kwargs):
-        data = FireXJsonReportGenerator.get_common_run_data(uid=uid, chain=chain,
-            submission_dir=submission_dir, argv=argv, original_cli=original_cli)
+    def create_initial_run_json(uid, chain, submission_dir, argv, original_cli=None, json_file=None,
+                                **inputs):
+        data = FireXJsonReportGenerator.get_common_run_data(uid=uid,
+                                                            chain=chain,
+                                                            submission_dir=submission_dir,
+                                                            argv=argv,
+                                                            original_cli=original_cli,
+                                                            inputs=inputs)
         data['completed'] = False
         data['revoked'] = False
         report_file = os.path.join(uid.logs_dir, FireXJsonReportGenerator.reporter_dirname,
-            FireXJsonReportGenerator.initial_report_filename)
+                                   FireXJsonReportGenerator.initial_report_filename)
         FireXJsonReportGenerator.write_report_file(data, report_file)
 
         report_link = os.path.join(uid.logs_dir, FireXJsonReportGenerator.report_link_filename)
@@ -87,14 +96,19 @@ class FireXJsonReportGenerator:
                              f'post_run must have already created the link to {report_link}')
 
     @staticmethod
-    def create_completed_run_json(uid, chain, root_id, submission_dir, argv, original_cli, json_file, run_revoked):
-        data = FireXJsonReportGenerator.get_common_run_data(
-            uid=uid, chain=chain, submission_dir=submission_dir, argv=argv, original_cli=original_cli)
+    def create_completed_run_json(uid, chain, root_id, submission_dir, argv, run_revoked, original_cli=None,
+                                  json_file=None, **inputs):
+        data = FireXJsonReportGenerator.get_common_run_data(uid=uid,
+                                                            chain=chain,
+                                                            submission_dir=submission_dir,
+                                                            argv=argv,
+                                                            original_cli=original_cli,
+                                                            inputs=inputs)
         data['completed'] = True
         data['results'] = get_results(root_id)
         data['revoked'] = run_revoked
         report_file = os.path.join(uid.logs_dir, FireXJsonReportGenerator.reporter_dirname,
-            FireXJsonReportGenerator.completion_report_filename)
+                                   FireXJsonReportGenerator.completion_report_filename)
 
         FireXJsonReportGenerator.write_report_file(data, report_file)
 
@@ -109,6 +123,7 @@ class FireXJsonReportGenerator:
                 # This is expected for most cases
                 pass
 
+
 def get_completion_report_data(logs_dir):
     report_file = os.path.join(logs_dir, FireXJsonReportGenerator.reporter_dirname,
                                FireXJsonReportGenerator.completion_report_filename)
@@ -116,7 +131,11 @@ def get_completion_report_data(logs_dir):
         return json.load(fp=f)
 
 
-def load_completion_report(json_file) -> FireXRunData:
+def is_completed_report(json_file: str) -> bool:
+    return os.path.basename(os.path.realpath(json_file)) == FireXJsonReportGenerator.completion_report_filename
+
+
+def load_completion_report(json_file: str) -> FireXRunData:
     assert os.path.isfile(json_file), f"File doesn't exist: {json_file}"
 
     with open(json_file) as f:
