@@ -28,7 +28,7 @@ from firexapp.submit.arguments import InputConverter, ChainArgException, get_cha
 from firexapp.submit.tracking_service import get_tracking_services, get_service_name
 from firexapp.plugins import plugin_support_parser
 from firexapp.submit.console import setup_console_logging
-from firexapp.application import import_microservices, get_app_tasks, get_app_task
+from firexapp.application import import_microservices, get_app_tasks, get_app_task, JSON_ARGS_PATH_ARG_NAME
 from firexapp.engine.celery import app
 from firexapp.broker_manager.broker_factory import BrokerFactory
 from firexapp.submit.shutdown import launch_background_shutdown, DEFAULT_CELERY_SHUTDOWN_TIMEOUT
@@ -47,6 +47,7 @@ FileRegistry().register_file(SUBMISSION_FILE_REGISTRY_KEY, os.path.join(Uid.debu
 ENVIRON_FILE_REGISTRY_KEY = 'env'
 FileRegistry().register_file(ENVIRON_FILE_REGISTRY_KEY, os.path.join(Uid.debug_dirname, 'environ.json'))
 
+RUN_SOFT_TIME_LIMIT_KEY = 'run_soft_time_limit'
 
 class JsonFileAction(argparse.Action):
     def __call__(self, parser, namespace, values, option_string=None):
@@ -83,16 +84,9 @@ class AdjustCeleryConcurrency(argparse.Action):
 
 def safe_create_completed_run_json(chain_result, run_revoked, chain_args):
     try:
-        FireXJsonReportGenerator.create_completed_run_json(
-            uid=chain_args['uid'],
-            chain=chain_args['chain'],
-            root_id=chain_result,
-            submission_dir=chain_args['submission_dir'],
-            argv=chain_args['argv'],
-            original_cli=chain_args.get('original_cli'),
-            json_file=chain_args.get('json_file'),
-            run_revoked=run_revoked,
-        )
+        FireXJsonReportGenerator.create_completed_run_json(root_id=chain_result,
+                                                           run_revoked=run_revoked,
+                                                           **chain_args)
     except Exception as e:
         logger.error(f'Failed to generate completion run JSON: {e}')
 
@@ -180,13 +174,16 @@ class SubmitBaseApp:
                                    help='Number of worker slots in celery pool',
                                    # default is autoscale from a minimum of cpu_count, to a maximum of 8*cpu_count
                                    default=None)
-        submit_parser.add_argument('--json_file', help='Link name for the report json file', action=JsonFileAction)
+        submit_parser.add_argument('--json_file', '--json_results_file', help='Link name for the report json file', action=JsonFileAction)
         submit_parser.add_argument('--tracking_services_wait_release_console',
                                    help='Wait for tracking services (e.g. Flame) to indicate they are ready to release '
                                         'the console before doing so.', nargs='?', const=True,
                                    default=True, action=OptionalBoolean)
         submit_parser.add_argument('--celery_shutdown_timeout', help='How long to wait in seconds for Celery during shutdown.',
                                    default=DEFAULT_CELERY_SHUTDOWN_TIMEOUT, type=int)
+        submit_parser.add_argument(JSON_ARGS_PATH_ARG_NAME,
+                                   help='Specify submit arguments via a JSON file containing a list of argument names and values.')
+
 
         submit_parser.set_defaults(func=self.run_submit)
 
@@ -374,6 +371,8 @@ class SubmitBaseApp:
             app.backend.set('uid', str(uid))
             app.backend.set('logs_dir', uid.logs_dir)
             app.backend.set('resources_dir', uid.resources_dir)
+            if args.soft_time_limit:
+                app.backend.set(RUN_SOFT_TIME_LIMIT_KEY, args.soft_time_limit)
 
             # IMPORT ALL THE MICROSERVICES
             # ONLY AFTER BROKER HAD STARTED
@@ -458,6 +457,7 @@ class SubmitBaseApp:
         chain_args['submission_dir'] = os.getcwd()
         chain_args['argv'] = sys.argv
         chain_args['json_file'] = args.json_file
+
         whitelist_arguments(['submitter', 'submission_dir', 'argv'])
 
         return chain_args
@@ -640,7 +640,9 @@ class FireXReturnCodeException(Exception):
         return self.error_msg + '\n' + f'[RC {self.firex_returncode}]'
 
 
-def get_unsuccessful_items(list_of_tasks):
+def get_unsuccessful_items(list_of_tasks, filters=None):
+    if not filters:
+        filters = []
     failures_by_name = {}
     for task_async_result in list_of_tasks:
         task_name = get_task_name_from_result(task_async_result)
@@ -650,6 +652,15 @@ def get_unsuccessful_items(list_of_tasks):
             failures_by_name[task_name] = 1
     formatted_list = []
     for task_name, instances in failures_by_name.items():
+        # Apply filters
+        ignore = False
+        for f in filters:
+            if re.fullmatch(f, task_name):
+                ignore = True
+                break
+        if ignore:
+            continue
+        # Record the failed task
         item = f'\t- {task_name}'
         if instances > 1:
             item += f' ({instances} instances)'
